@@ -1,8 +1,7 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 #ifndef _GNM_RANGEFUNC_STRINGS_H_
 # define _GNM_RANGEFUNC_STRINGS_H_
 
-#include "numbers.h"
+#include <numbers.h>
 
 G_BEGIN_DECLS
 
